summaryrefslogtreecommitdiff
path: root/src/resolve/resolved-dns-zone.c
diff options
context:
space:
mode:
authorLennart Poettering <lennart@poettering.net>2014-08-10 22:48:16 +0200
committerLennart Poettering <lennart@poettering.net>2014-08-11 15:06:22 +0200
commit4d91eec42d3ba547c4e2578df0d6fd568075647b (patch)
tree0017e196985a4d20a0d0d587314ad7b926233589 /src/resolve/resolved-dns-zone.c
parent3ef64445cdf12d7703aa79b39f3c170037d587c7 (diff)
downloadsystemd-4d91eec42d3ba547c4e2578df0d6fd568075647b.tar.gz
resolved: actually, the peer with the lower IP address wins conflicts
Diffstat (limited to 'src/resolve/resolved-dns-zone.c')
-rw-r--r--src/resolve/resolved-dns-zone.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/resolve/resolved-dns-zone.c b/src/resolve/resolved-dns-zone.c
index ebbd1e2bf1..370ecefd79 100644
--- a/src/resolve/resolved-dns-zone.c
+++ b/src/resolve/resolved-dns-zone.c
@@ -527,7 +527,7 @@ void dns_zone_item_ready(DnsZoneItem *i) {
/* The probe got a successful reply. If we so far
* weren't established we just give up. If we already
* were established, and the peer has the
* lexicographically smaller IP address we continue
* and defend it. */
if (!IN_SET(i->state, DNS_ZONE_ITEM_ESTABLISHED, DNS_ZONE_ITEM_VERIFYING)) {
@@ -535,9 +535,9 @@ void dns_zone_item_ready(DnsZoneItem *i) {
we_lost = true;
} else {
assert(i->probe_transaction->received);
- we_lost = memcmp(&i->probe_transaction->received->sender, &i->probe_transaction->received->destination, FAMILY_ADDRESS_SIZE(i->probe_transaction->received->family)) > 0;
+ we_lost = memcmp(&i->probe_transaction->received->sender, &i->probe_transaction->received->destination, FAMILY_ADDRESS_SIZE(i->probe_transaction->received->family)) < 0;
if (we_lost)
- log_debug("Got a successful probe reply for an established RR, and we have a lexicographically lower IP address and thus lost.");
+ log_debug("Got a successful probe reply for an established RR, and we have a lexicographically larger IP address and thus lost.");
}
if (we_lost) {
@@ -527,7 +527,7 @@ void dns_zone_item_ready(DnsZoneItem *i) {
* weren't established we just give up. If we already
* were established, and the peer has the
- * lexicographically smaller IP address we continue
+ * lexicographically larger IP address we continue
* and defend it. */
if (!IN_SET(i->state, DNS_ZONE_ITEM_ESTABLISHED, DNS_ZONE_ITEM_VERIFYING)) {